@@ -1,6 +1,6 @@
 ;;; org-colview.el --- Column View in Org-mode
 
-;; Copyright (C) 2004-2014 Free Software Foundation, Inc.
+;; Copyright (C) 2004-2016 Free Software Foundation, Inc.
 
 ;; Author: Carsten Dominik <carsten at orgmode dot org>
 ;; Keywords: outlines, hypermedia, calendar, wp
@@ -31,7 +31,7 @@
 (eval-when-compile (require 'cl))
 (require 'org)
 
-(declare-function org-agenda-redo "org-agenda" ())
+(declare-function org-agenda-redo "org-agenda" (&optional all))
 (declare-function org-agenda-do-context-action "org-agenda" ())
 (declare-function org-clock-sum-today "org-clock" (&optional headline-filter))
 
@@ -146,11 +146,15 @@ This is the compiled version of the format.")
     "--"
     ["Quit" org-columns-quit t]))
 
+(defun org-columns--value (property pos)
+  "Return value for PROPERTY at buffer position POS."
+  (or (cdr (assoc-string property (get-text-property pos 'org-summaries) t))
+      (org-entry-get pos property 'selective t)))
+
 (defun org-columns-new-overlay (beg end &optional string face)
   "Create a new column overlay and add it to the list."
   (let ((ov (make-overlay beg end)))
     (overlay-put ov 'face (or face 'secondary-selection))
-    (remove-text-properties 0 (length string) '(face nil) string)
     (org-overlay-display ov string face)
     (push ov org-columns-overlays)
     ov))
@@ -206,9 +210,7 @@ This is the compiled version of the format.")
 	       (val (or (cdr ass) ""))
 	       (modval
 		(cond
-		 ((and org-columns-modify-value-for-display-function
-		       (functionp
-			org-columns-modify-value-for-display-function))
+		 ((functionp org-columns-modify-value-for-display-function)
 		  (funcall org-columns-modify-value-for-display-function
 			   title val))
 		 ((equal property "ITEM") (org-columns-compact-links val))
@@ -220,7 +222,23 @@ This is the compiled version of the format.")
 		  (org-columns-number-to-string
 		   (funcall calc (org-columns-string-to-number val fm)) fm))))
 	       (string
-		(format f (org-columns-add-ellipses (or modval val) width)))
+		(format f
+			(let ((v (org-columns-add-ellipses
+				  (or modval val) width)))
+			  (cond
+			   ((equal property "PRIORITY")
+			    (propertize v 'face (org-get-priority-face val)))
+			   ((equal property "TAGS")
+			    (if (not org-tags-special-faces-re)
+				(propertize v 'face 'org-tag)
+			      (replace-regexp-in-string
+			       org-tags-special-faces-re
+			       (lambda (m)
+				 (propertize m 'face (org-get-tag-face m)))
+			       v nil nil 1)))
+			   ((equal property "TODO")
+			    (propertize v 'face (org-get-todo-face val)))
+			   (t v)))))
 	       (ov (org-columns-new-overlay
 		    (point) (1+ (point)) string (if dateline face1 face))))
 	  (overlay-put ov 'keymap org-columns-map)
@@ -530,7 +548,7 @@ Where possible, use the standard interface for changing this line."
       (condition-case nil (org-no-warnings (next-line 1)) (error nil))
       (setq hidep (org-at-heading-p 1)))
     (eval form)
-    (and hidep (hide-entry))))
+    (and hidep (outline-hide-entry))))
 
 (defun org-columns-previous-allowed-value ()
   "Switch to the previous allowed value for this column."
@@ -589,7 +607,7 @@ an integer, select that value."
        (t (setq nval (car allowed)))))
     (cond
      ((equal major-mode 'org-agenda-mode)
-      (org-columns-eval '(org-entry-put pom key nval))
+      (org-columns-eval `(org-entry-put ,pom ,key ,nval))
       ;; The following let preserves the current format, and makes sure
       ;; that in only a single file things need to be updated.
       (let* ((org-agenda-overriding-columns-format org-columns-current-fmt)
@@ -600,13 +618,13 @@ an integer, select that value."
 	(org-agenda-columns)))
      (t
       (let ((inhibit-read-only t))
-	(remove-text-properties (1- bol) eol '(read-only t))
+	(remove-text-properties (max (1- bol) (point-min)) eol '(read-only t))
 	(unwind-protect
 	    (progn
 	      (setq org-columns-overlays
 		    (org-delete-all line-overlays org-columns-overlays))
 	      (mapc 'delete-overlay line-overlays)
-	      (org-columns-eval '(org-entry-put pom key nval)))
+	      (org-columns-eval `(org-entry-put ,pom ,key ,nval)))
 	  (org-columns-display-here)))
       (org-move-to-column col)
       (and (nth 3 (assoc-string key org-columns-current-fmt-compiled t))
@@ -662,11 +680,14 @@ around it."
     fmt))
 
 (defun org-columns-goto-top-level ()
-  (when (condition-case nil (org-back-to-heading) (error nil))
-    (org-entry-get nil "COLUMNS" t))
-  (if (marker-position org-entry-property-inherited-from)
-      (move-marker org-columns-top-level-marker org-entry-property-inherited-from)
-    (move-marker org-columns-top-level-marker (point))))
+  "Move to the beginning of the column view area.
+Also sets `org-columns-top-level-marker' to the new position."
+  (goto-char
+   (move-marker
+    org-columns-top-level-marker
+    (cond ((org-before-first-heading-p) (point-min))
+	  ((org-entry-get nil "COLUMNS" t) org-entry-property-inherited-from)
+	  (t (org-back-to-heading) (point))))))
 
 ;;;###autoload
 (defun org-columns (&optional columns-fmt-string)
@@ -685,9 +706,8 @@ When COLUMNS-FMT-STRING is non-nil, use it as the column format."
   (save-excursion
     (save-restriction
       (narrow-to-region
-       org-columns-top-level-marker
-       (or (ignore-errors (org-end-of-subtree t t)) (point-max)))
-      (goto-char (point-min))
+       (point)
+       (if (org-at-heading-p) (org-end-of-subtree t t) (point-max)))
       (when (assoc "CLOCKSUM" org-columns-current-fmt-compiled)
 	(org-clock-sum))
       (when (assoc "CLOCKSUM_T" org-columns-current-fmt-compiled)
@@ -697,10 +717,9 @@ When COLUMNS-FMT-STRING is non-nil, use it as the column format."
 	      (org-map-entries
 	       (lambda ()
 		 (cons (point)
-		       (mapcar
-			(lambda (p)
-			  (cons p (org-entry-get nil p 'selective t)))
-			column-names)))
+		       (mapcar (lambda (p)
+				 (cons p (org-columns--value p (point))))
+			       column-names)))
 	       nil nil (and org-columns-skip-archived-trees 'archive))))
 	(when cache
 	  (org-set-local 'org-columns-current-maxwidths
@@ -1174,47 +1193,41 @@ This function updates `org-columns-current-fmt-compiled'."
 
 ;;; Dynamic block for Column view
 
-(defvar org-heading-regexp) ; defined in org.el
-(defvar org-heading-keyword-regexp-format) ; defined in org.el
 (defun org-columns-capture-view (&optional maxlevel skip-empty-rows)
   "Get the column view of the current buffer or subtree.
-The first optional argument MAXLEVEL sets the level limit.  A
-second optional argument SKIP-EMPTY-ROWS tells whether to skip
+The first optional argument MAXLEVEL sets the level limit.
+A second optional argument SKIP-EMPTY-ROWS tells whether to skip
 empty rows, an empty row being one where all the column view
-specifiers except ITEM are empty.  This function returns a list
+specifiers but ITEM are empty.  This function returns a list
 containing the title row and all other rows.  Each row is a list
 of fields."
   (save-excursion
-    (let* ((title (mapcar 'cadr org-columns-current-fmt-compiled))
-	   (re-archive (concat ".*:" org-archive-tag ":"))
-	   (n (length title)) row tbl)
+    (let* ((title (mapcar #'cadr org-columns-current-fmt-compiled))
+	   (has-item? (member "ITEM" title))
+	   (n (length title))
+	   tbl)
       (goto-char (point-min))
-      (while (re-search-forward org-heading-regexp nil t)
+      (while (re-search-forward org-outline-regexp-bol nil t)
 	(catch 'next
 	  (when (and (or (null maxlevel)
-			 (>= maxlevel
-			     (if org-odd-levels-only
-				 (/ (1+ (length (match-string 1))) 2)
-			       (length (match-string 1)))))
+			 (>= maxlevel (org-reduced-level (org-outline-level))))
 		     (get-char-property (match-beginning 0) 'org-columns-key))
 	    (when (or (org-in-commented-heading-p t)
-		      (save-excursion
-			(beginning-of-line)
-			(looking-at re-archive)))
+		      (member org-archive-tag (org-get-tags)))
 	      (org-end-of-subtree t)
 	      (throw 'next t))
-	    (setq row nil)
-	    (loop for i from 0 to (1- n) do
-		  (push
-		   (org-quote-vert
-		    (or (get-char-property (+ (match-beginning 0) i) 'org-columns-value-modified)
-			(get-char-property (+ (match-beginning 0) i) 'org-columns-value)
-			""))
-		   row))
-	    (setq row (nreverse row))
-	    (unless (and skip-empty-rows
-			 (eq 1 (length (delete "" (delete-dups (copy-sequence row))))))
-	      (push row tbl)))))
+	    (let (row)
+	      (dotimes (i n)
+		(let ((col (+ (line-beginning-position) i)))
+		  (push (org-quote-vert
+			 (or (get-char-property col 'org-columns-value-modified)
+			     (get-char-property col 'org-columns-value)
+			     ""))
+			row)))
+	      (unless (and skip-empty-rows
+			   (let ((r (delete-dups (remove "" row))))
+			     (or (null r) (and has-item? (= (length r) 1)))))
+		(push (nreverse row) tbl))))))
       (append (list title 'hline) (nreverse tbl)))))
 
 ;;;###autoload
@@ -1397,7 +1410,7 @@ and tailing newline characters."
 		(org-with-point-at m
 		  (mapcar
 		   (lambda (name)
-		     (let ((value (org-entry-get (point) name 'selective t)))
+		     (let ((value (org-columns--value name (point))))
 		       (cons
 			name
 			(if (and org-agenda-columns-add-appointments-to-effort-sum
